<!DOCTYPE html>
{% load static %}
{% load evelinks %}
{% load tnnt_template_tags %}

<html lang="en">
    <head>
        <meta charset="utf-8">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <meta name="viewport" content="width=device-width, initial-scale=1">
        <meta name="description" content="">
        <meta name="author" content="">

        {% include "tnnt_templates/includes/opengraph-tags.html" %}
        {% include 'allianceauth/icons.html' %}

        <title>{% block title %}{% block page_title %}{% endblock page_title %} » {{ SITE_NAME }}{% endblock title %}</title>

        {% include 'bundles/bootstrap-css.html' %}
        {% include 'bundles/fontawesome.html' %}

        {% block extra_include %}
        {% endblock %}

        <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/terra-nanotech-defaults.min.css' %}">
        <link rel="stylesheet" href="{% tnnt_static 'tnnt_templates/css/terra-nanotech-public.min.css' %}">

        <style>
            {% block extra_style %}
            {% endblock %}
        </style>
    </head>

    <body>
        <div class="auth-login-box">
            {% block content %}
            {% endblock %}
        </div>

        <div class="tnnt-aa-svg-wrapper">
            {% include "tnnt_templates/bundles/svg/ccp_sso.svg" %}
        </div>
    </body>
</html>
