{% extends 'allianceauth/base.html' %}

{% load i18n %}

{% block page_title %}{% trans "Blacklist" %}{% endblock %}

{% block extra_css %}
    {% include 'bundles/datatables-css.html' %}
{% endblock extra_css %}

{% block content %}
    <div class="col-lg-12">
        {% block tb_block %}{% endblock %}
    </div>
{% endblock %}
