@media all {
    * {
        background-color: var(--background-darkmode-color-default) !important;
        background-image: none !important;
        border-color: var(--border-color-darkmode-default) !important;
        color: var(--color-darkmode-default) !important;
        font-family: monospace;
    }

    .nav-pills > li > a.active,
    .nav-pills > li > a:hover {
        background-color: var(--background-color-darkmode-navigation-default-active) !important;
        color: var(--background-darkmode-color-default) !important;
    }

    .nav-pills > li > a.active i,
    .nav-pills > li > a:hover i {
        background-color: transparent !important;
        color: var(--background-darkmode-color-default) !important;
    }

    .template-dark-mode .nav-tabs > li.active > a {
        background-color: var(--background-color-darkmode-navigation-default-active) !important;
        color: var(--background-darkmode-color-default) !important;
    }

    .badge {
        background-color: var(--background-color-darkmode-navigation-default-active) !important;
        color: var(--background-darkmode-color-default) !important;
    }
}

/* AA Memberaudit
------------------------------------------------------------------------------------- */
@media all {
    .template-dark-mode .aa-memberaudit .nav-tabs > li.active > a {
        background-color: var(--background-color-darkmode-navigation-default-active) !important;
        color: var(--background-darkmode-color-default) !important;
    }
}

/* AA Fittings
------------------------------------------------------------------------------------- */
@media all {
    #Fitting_Panel,
    #Fitting_Panel * {
        background-color: transparent !important;
    }
}
