 /*!
  Theme: nnfx light
  Description: a theme inspired by Netscape Navigator/Firefox
  Author: (c) 2020-2021 Jim Mason <jmason@ibinx.com>
  Maintainer: @RocketMan
  License: https://creativecommons.org/licenses/by-sa/4.0  CC BY-SA 4.0
  Updated: 2021-05-17

  @version 1.1.0
*/

.hljs {
  background: #fff;
  color: #000;
}

.language-xml .hljs-meta,
.language-xml .hljs-meta-string {
  font-weight: bold;
  font-style: italic;
  color: #48b;
}

.hljs-comment,
.hljs-quote {
  font-style: italic;
  color: #070;
}

.hljs-name,
.hljs-keyword,
.hljs-built_in {
  color: #808;
}

.hljs-name,
.hljs-attr {
  font-weight: bold;
}

.hljs-string {
  font-weight: normal;
}

.hljs-code,
.hljs-string,
.hljs-meta .hljs-string,
.hljs-number,
.hljs-regexp,
.hljs-link {
  color: #00f;
}

.hljs-title,
.hljs-symbol,
.hljs-bullet,
.hljs-variable,
.hljs-template-variable {
  color: #f40;
}

.hljs-title.class_,
.hljs-class .hljs-title,
.hljs-type {
  font-weight: bold;
  color: #639;
}

.hljs-title.function_,
.hljs-function .hljs-title,
.hljs-attr,
.hljs-subst,
.hljs-tag {
  color: #000;
}

.hljs-formula {
  background-color: #eee;
  font-style: italic;
}

.hljs-addition {
  background-color: #beb;
}

.hljs-deletion {
  background-color: #fbb;
}

.hljs-meta {
  color: #269;
}

.hljs-section,
.hljs-selector-id,
.hljs-selector-class,
.hljs-selector-pseudo,
.hljs-selector-tag {
  font-weight: bold;
  color: #48b;
}

.hljs-selector-pseudo {
  font-style: italic;
}

.hljs-doctag,
.hljs-strong {
  font-weight: bold;
}

.hljs-emphasis {
  font-style: italic;
}
